/*
 * Copyright (c)1997 by Dianne Hackborn.
 * All rights reserved.
 *
 * Various classes and definitions that I find useful.
 *
 * This code is not public domain, nor freely distributable.
 * Please direct any questions or requests to Dianne Hackborn,
 * at <hackbod@lucent.com> or <hackbod@enteract.com>.
 *
 * ----------------------------------------------------------------------
 *
 * ArpColor.h
 *
 * A class wrapper around rgb_color.
 *
 * ----------------------------------------------------------------------
 *
 * Known Bugs
 * ~~~~~~~~~~
 *
 * ----------------------------------------------------------------------
 *
 * To Do
 * ~~~~~
 *
 * • Add methods for creating ArpColor objects that are scaled
 *   between two other colors.
 *
 * ----------------------------------------------------------------------
 *
 * History
 * ~~~~~~~
 *
 * 0.1: Created this file.
 *
 */

#pragma once

#ifndef ARPCOMMON_ARPCOLOR_H
#define ARPCOMMON_ARPCOLOR_H

#ifndef _VIEW_H
#include <View.h>
#endif

#pragma export on

class ArpColor {

public:

	ArpColor() {
		color.red = color.green = color.blue = color.alpha = 0;
	}
	
	ArpColor(uchar red,uchar green,uchar blue,uchar alpha=0) {
		color.red = red;
		color.green = green;
		color.blue = blue;
		color.alpha = alpha;
	};
	
	ArpColor(long int mycol) {
		color.red = (mycol>>16)&0xff;
		color.green = (mycol>>8)&0xff;
		color.blue = mycol&0xff;
		color.alpha = (mycol>>24)&0xff;
	}
	
	ArpColor(const rgb_color & mycol) {
		color.red = mycol.red;
		color.green = mycol.green;
		color.blue = mycol.blue;
		color.alpha = mycol.alpha;
	};

	ArpColor(const ArpColor & mycol) {
		color.red = mycol.color.red;
		color.green = mycol.color.green;
		color.blue = mycol.color.blue;
		color.alpha = mycol.color.alpha;
	};

	~ArpColor() {
	}

	static const ArpColor Black;
	static const ArpColor White;
	static const ArpColor Red;
	static const ArpColor Green;
	static const ArpColor Blue;
	static const ArpColor Purple;
	static const ArpColor Yellow;
	static const ArpColor Cyan;
	static const ArpColor Transparent;
	
	operator rgb_color () const {
		return color;
	}

	operator const rgb_color& () const {
		return color;
	}

	operator const rgb_color* () const {
		return &color;
	}

	ArpColor& operator = (const ArpColor & set) {
		color.red = set.color.red;
		color.green = set.color.green;
		color.blue = set.color.blue;
		color.alpha = set.color.alpha;
		return *this;
	}
			
	ArpColor& operator = (const rgb_color & set) {
		color.red = set.red;
		color.green = set.green;
		color.blue = set.blue;
		color.alpha = set.alpha;
		return *this;
	}
			
	bool operator == (const ArpColor & comp) {
		return (color.red==comp.color.red
				&& color.green==comp.color.green
				&& color.blue==comp.color.blue
				&& color.alpha==comp.color.alpha);
	}
			
	bool operator == (const rgb_color & comp) {
		return (color.red==comp.red
				&& color.green==comp.green
				&& color.blue==comp.blue
				&& color.alpha==comp.alpha);
	}
	
	uchar GetRed(void) { return color.red; }
	uchar GetGreen(void) { return color.green; }
	uchar GetBlue(void) { return color.blue; }
	uchar GetAlpha(void) { return color.alpha; }
	float GetGray(void) {
		return ( (color.red+color.green+color.blue)
				 / (3.0*256.0) );
	}
	
private:

	rgb_color color;
	uchar index;
};

#pragma export off

#endif
