/*
 * Copyright (c)1997 by Dianne Hackborn.
 * All rights reserved.
 *
 * Various classes and definitions that I find useful.
 *
 * This code is not public domain, nor freely distributable.
 * Please direct any questions or requests to Dianne Hackborn,
 * at <hackbod@lucent.com> or <hackbod@enteract.com>.
 *
 * ----------------------------------------------------------------------
 *
 * ArpDebug.h
 *
 * Helper macros for program debugging...  based on
 * the macros commonly used under AmigaOS.  Use '#define DEBUG 1'
 * to turn on the macros.
 *
 * ----------------------------------------------------------------------
 *
 * Known Bugs
 * ~~~~~~~~~~
 *
 * ----------------------------------------------------------------------
 *
 * To Do
 * ~~~~~
 *
 * ----------------------------------------------------------------------
 *
 * History
 * ~~~~~~~
 *
 * 0.1: Created this file.
 *
 */

#pragma once

#ifndef ARPCOMMON_ARPDEBUG_H
#define ARPCOMMON_ARPDEBUG_H

#include <assert.h>

#include <support/Debug.h>

#define RPTERR(ARGS)	_debugPrintf ARGS

#if DEBUG

#ifndef DB_DELAY
#define DB_WAIT(x)
#else
#define DB_WAIT(x) snooze(x)
#endif

#define D(x) x
#define DB(level,x) { if(level) { x; } cdb.flush(); DB_WAIT(DB_DELAY) }
#define DBALL 0xffff
#define cdb cerr
#define stddb stdout
#define bug fprintf
#else
#define DB_WAIT(x)
#define D(x)
#define DB(level,x)
#define DBALL 0
#define bug
#endif

#if defined(DEBUG) || defined(USE_STREAMS)
#include <iostream.h>

#ifndef ARPCOMMON_ARPSTRING_H
#include "ArpCommon/ArpString.h"
#endif

#ifndef ARPCOMMON_ARPCOLOR_H
#include "ArpCommon/ArpColor.h"
#endif

// We only define these stream operators when debugging is turned
// on, since using streams bloats code so much...

inline ostream& operator << (ostream& os, const ArpString & str)
{ os << (const char*)str; return os; }

class BPoint;
class BRect;
class BFont;
class BMessenger;
class BMessage;
class BPath;
struct entry_ref;
struct rgb_color;
struct pattern;

ostream& operator << (ostream& os, const BPoint & bp);
ostream& operator << (ostream& os, const BRect & br);
ostream& operator << (ostream& os, const BFont & fn);
ostream& operator << (ostream& os, const BMessenger & o);
ostream& operator << (ostream& os, const BPath & o);
ostream& operator << (ostream& os, const entry_ref & o);
ostream& operator << (ostream& os, const rgb_color & o);
ostream& operator << (ostream& os, const pattern & o);
ostream& operator << (ostream& os, const BMessage & msg);

#endif
	
#endif
