/*
 * Copyright (c)1997 by Dianne Hackborn.
 * All rights reserved.
 *
 * Based (increasingly loosly) on WebTerm, a Web-based terminal
 * applet written in Java, which is
 * Copyright (C)1996 by the National Alliance for Computational
 * Science and Engineering (NACSE).
 * See <URL:http://www.nacse.org/> for more information.
 *
 * This code is not public domain, nor freely distributable.
 * Please direct any questions or requests to Dianne Hackborn,
 * at <hackbod@lucent.com> or <hackbod@enteract.com>.
 *
 * ----------------------------------------------------------------------
 *
 * ArpEmulatorAddon.h
 *
 * This file describes the interface that emulator add-ons
 * supply in their global name space.
 *
 * ----------------------------------------------------------------------
 *
 * Known Bugs
 * ~~~~~~~~~~
 *
 * ----------------------------------------------------------------------
 *
 * History
 * ~~~~~~~
 *
 * 7/19/97:
 *	Created file from ArpEmulatorInterface.h
 *
 */

#pragma once

#ifndef ARPCOMMON_ARPEMULATORADDON_H
#define ARPCOMMON_ARPEMULATORADDON_H

#ifndef ARPCOMMON_ARPEMULATORINTERFACE_H
#include <ArpCommon/ArpEmulatorInterface.h>
#endif

#pragma export on

typedef enum {
	ArpEmulator_Current = 1
} ArpEmulatorVersion;

struct ArpEmulatorAddon {
	ArpEmulatorVersion InterfaceVersion;	// ArpEmulator_Current
	
	const char* Name;			// Official long name of add-on
	const char* Company;		// Company that created add-on
	const char* Copyright;		// Copyright informtion
	
	const char* BuildDate;		// __DATE__
	const char* BuildTime;		// __TIME__
	
	int32 Version;				// Addon-specific version code
	
	const char* Description;	// Lots of enlightening information
	
	int32 (*CountEmulations)(void);
	const ArpEmulationType* (*EmulationType)(int32 idx);
	ArpEmulatorInterface* (*AllocEmulator)(const char* name,
											ArpTerminalInterface& terminal);
};

typedef const ArpEmulatorAddon* (ArpEmulatorAddonFunc)(void);

extern ArpEmulatorAddonFunc GetEmulatorAddon;

#pragma export reset

#endif
