/*
 * Copyright (c)1997 by Dianne Hackborn.
 * All rights reserved.
 *
 * Various classes and definitions that I find useful.
 *
 * This code is not public domain, nor freely distributable.
 * Please direct any questions or requests to Dianne Hackborn,
 * at <hackbod@lucent.com> or <hackbod@enteract.com>.
 *
 * ----------------------------------------------------------------------
 *
 * ArpEmulatorManager.h
 *
 * This class keeps track of all the emulations available
 * to the terminal -- both those that are a static part of
 * the program, and through external add-ons.  There is usually
 * only one of these objects for an entire application.
 *
 * ----------------------------------------------------------------------
 *
 * Known Bugs
 * ~~~~~~~~~~
 *
 *	• This class keeps the image of every add-on it find loaded
 *	  in memory for the lifetime of the object.  It really really
 *	  shouldn't do this; we should probably stash a way the info
 *	  we need on the add-on in the files attributes so that we
 *	  can avoid opening it when first scanning add-ons, and need
 *	  to define a way to find out when ArpEmulatorInterface
 *	  objects are no longer being used...
 *
 * ----------------------------------------------------------------------
 *
 * To Do
 * ~~~~~
 *
 * ----------------------------------------------------------------------
 *
 * History
 * ~~~~~~~
 *
 * 7/22/97:
 *	Created this file.
 *
 */

#pragma once

#ifndef ARPCOMMON_ARPEMULATORMANAGER_H
#define ARPCOMMON_ARPEMULATORMANAGER_H

#ifndef ARPCOMMON_ARPADDONMANAGER_H
#include <ArpCommon/ArpAddonManager.h>
#endif

#ifndef ARPCOMMON_ARPEMULATORADDON_H
#include <ArpCommon/ArpEmulatorAddon.h>
#endif

#ifndef ARPCOMMON_ARPTERMINALINTERFACE_H
#include <ArpCommon/ArpTerminalInterface.h>
#endif

#pragma export on

class ArpEmulatorManager : public ArpAddonManager {

public:

	// Define the addition information we store about each add-on.
	class EmulatorAddon : public BasicAddon {
	public:
		EmulatorAddon(BEntry* entry);
		EmulatorAddon(const ArpEmulatorAddon* emulator);
		~EmulatorAddon();
	
		virtual status_t InitCheck(void) const;
		
		const ArpEmulatorAddon* GetEmulator(void) const;
		
	private:
		const ArpEmulatorAddon* interface;
	};

	/* This function can be used to place into the add-on list
	   emulators that are a static part of the executable.
	   Calling it results in an EmulatorAddon being created
	   which has not been initialized; the ArpAddonManager
	   subclass ignores such objects.
	*/
	void AddStaticEmulator(const ArpEmulatorAddon* emulator);
	
	/* Override the menu creator to extract many names from
	   the array of emulation types available in each add-on.
	*/
	int32 CreateAddonMenu(BMenu* inmenu, BMessage* tmpl = NULL) const;
	
	/* Return the emulator add-on that implements a particular
	   terminal type name.
	*/
	const ArpEmulatorAddon* EmulatorAddonForType(const char* name) const;
	
	/* Find the add-on that implements an emulation on the given
	   name and ask it to create a new object for us.
	*/
	ArpEmulatorInterface* AllocEmulator(const char* name,
									ArpTerminalInterface* terminal) const;
	
protected:
	virtual BasicAddon* AllocAddon(BEntry* entry);

};

#pragma export off

#endif
