/*
 * Copyright (c)1997 by Dianne Hackborn.
 * All rights reserved.
 *
 * Based (increasingly loosly) on WebTerm, a Web-based terminal
 * applet written in Java, which is
 * Copyright (C)1996 by the National Alliance for Computational
 * Science and Engineering (NACSE).
 * See <URL:http://www.nacse.org/> for more information.
 *
 * This code is not public domain, nor freely distributable.
 * Please direct any questions or requests to Dianne Hackborn,
 * at <hackbod@lucent.com> or <hackbod@enteract.com>.
 *
 * ----------------------------------------------------------------------
 *
 * ArpRemoteTerminal.h
 *
 * The ArpRemoteTerminal class is a subclass of ArpTerminal
 * that interacts with a BMessenger object as its data
 * source/sink.
 *
 * ----------------------------------------------------------------------
 *
 * Known Bugs
 * ~~~~~~~~~~
 *
 * ----------------------------------------------------------------------
 *
 * History
 * ~~~~~~~
 *
 * 7/25/97:
 *	• Removed the receive buffer code, as that was old, no
 *	  longer needed, and probably doing more harm than good.
 *
 * 0.1: Created this file from the WebTerm source.
 *
 */

#pragma once

#ifndef ARPCOMMON_ARPREMOTETERMINAL_H
#define ARPCOMMON_ARPREMOTETERMINAL_H

#ifndef _MESSENGER_H
#include <Messenger.h>
#endif

#ifndef ARPCOMMON_ARPTERMINAL_H
#include <ArpCommon/ArpTerminal.h>
#endif

#ifndef ARPCOMMON_ARPEMULATORMANAGER_H
#include "ArpCommon/ArpEmulatorManager.h"
#endif

#ifndef ARPCOMMON_ARPTERMINALMSG_H
#include "ArpCommon/ArpTerminalMsg.h"
#endif

class ArpRemoteTerminal : public ArpTerminal {
	
public:

	ArpRemoteTerminal(BRect frame, const char* name,
			 			uint32 resizeMode = B_FOLLOW_ALL_SIDES,
			 			uint32 flags = B_WILL_DRAW|B_FRAME_EVENTS|B_NAVIGABLE);
	virtual ~ArpRemoteTerminal();
	
	void UseEmulatorManager(ArpEmulatorManager* mgr);
	ArpEmulatorManager* EmulatorManager(void);
	
	void SetRemote(const BMessenger& dev);
	const BMessenger& Remote(void);
	
	ArpEmulatorInterface* SetEmulator(const char* name);
	ArpEmulatorInterface* SetEmulator(ArpEmulatorInterface* emu)
		{ return inherited::SetEmulator(emu); }
	
	virtual void TermSizeChanged(int32 rows, int32 cols);
	virtual void TermEmulationChanged(const char* name);

	// Send text from emulator to remote device.
	virtual void TermSendRemote(const ichar * d, size_t len);

	// Send text from remote device to emulator.
	virtual void MessageReceived(BMessage* message);
	virtual void AttachedToWindow(void);

protected:

	void SendAttachMsg(void);
	void SendSizeMsg(int32 rows, int32 cols);
	void SendEmulatorsMsg(void);
	
	/* ------------------------------------------------------------
	   IMPLEMENTATION SECTION
	   ------------------------------------------------------------ */

private:

	ArpEmulatorManager* manager;
	
	BMessenger device;
	BMessenger termhand;

#if 0
	ichar receiveBuffer[8192];
#endif
};

#endif
