/*
 * Copyright (c)1997 by Dianne Hackborn.
 * All rights reserved.
 *
 * Various classes and definitions that I find useful.
 *
 * This code is not public domain, nor freely distributable.
 * Please direct any questions or requests to Dianne Hackborn,
 * at <hackbod@lucent.com> or <hackbod@enteract.com>.
 *
 * ----------------------------------------------------------------------
 *
 * ArpString.h
 *
 * Based on CString.h
 * Copyright 1995 -1996 Metrowerks Corporation, All Rights Reserved.
 * Modified by Dianne Hackborn (hackbod@lucent.com), 1997
 *
 * General-purpose string class, modifed to support strings
 * with embedded nulls.
 *
 * ----------------------------------------------------------------------
 *
 * Known Bugs
 * ~~~~~~~~~~
 *
 * • SetLength() doesn't work.
 *
 * ----------------------------------------------------------------------
 *
 * To Do
 * ~~~~~
 *
 * • Extend to avoid doing all the malloc() and free()s and must
 *   do, currently every time the string changes.
 *
 * • Make a base class for static strings, which don't need to
 *   allocate their own storage.
 *
 * ----------------------------------------------------------------------
 *
 * History
 * ~~~~~~~
 *
 * 0.1: Created this file.
 *
 */

#pragma once

#ifndef ARPCOMMON_ARPSTRING_H
#define ARPCOMMON_ARPSTRING_H

#pragma once

#include <SupportDefs.h>

typedef uchar ichar;

#pragma export on

class ArpString
{
public:
	ArpString(void);
	ArpString(const ichar * init, int32 off=0, int32 cnt=-1);
	ArpString(const char * init, int32 off=0, int32 cnt=-1);
	ArpString(const ichar c);
	ArpString(long value, int32 radix=10);
	ArpString(float value);
	ArpString(const ArpString & clone);

	~ArpString();

	operator const ichar * () const;
	operator const char * () const;

	ichar operator [] ( int32 idx ) const
		{ return fData ? fData[idx] : 0; }

	bool operator == (const ArpString & compare) const;
	bool operator == (const ichar * compare) const;

	ArpString& operator + (const ArpString & add) const;
	ArpString& operator + (const ichar * add) const;
	ArpString& operator + (ichar add) const;
	ArpString& operator + (long add) const;
	ArpString& operator += (const ArpString & add);
	ArpString& operator += (const ichar * add);
	ArpString& operator += (ichar add);
	ArpString& operator += (long add);
	ArpString& operator = (const ArpString & clone);
	ArpString& operator = (const ichar * clone);
	ArpString& operator = (long clone);

	ArpString& Append(const ichar* str, int32 start, int32 len);
	ArpString& Insert(const ichar* inArpString, long inOffset);
	ArpString& Replace(const ichar* inArpString,
						long inOffset, long inLength);

	int32 OffsetOf(ichar inChar) const;
	int32 ROffsetOf(ichar inChar) const;

	void Set(const ichar * inText, long inLength);
		
	int32 Length() const		{ return fSize; }
	void SetLength(int32 newlen);

protected:
	void ReadFrom(const ichar * clone, int32 size);
	void ReadFrom(const char * clone, int32 size);
	
	ichar*	fData;
	int		fSize;
};


ichar *	p2istr(unsigned char * str);
unsigned char * i2pstr(ichar * str);
void p2istrncpy(ichar * cstr, const unsigned char * pstr, int32 maxLen);
void i2pstrncpy(unsigned char * cstr, const ichar * pstr, int32 maxLen);

#pragma export off

#endif
